@@ -586,7 +586,8 @@ def showSchema(gClient,gSpace,tabuEdgeList=["Alias","School"],tabuTagList=["alia
 def downloadGraph(gClient,
                     srcGdbName,srcFakeGdbName,
                     edgeTypeList=[],
-                    srcVertexKeynameDict={"srcNodeType":"srcNodeIdAttr"}):
+                    srcVertexKeynameDict={"srcNodeType":"srcNodeIdAttr"},
+                    sampleN=-1):
     
     '''以上传的格式下载图数据'''
     if "downloadGraph" not in os.listdir("."):
@@ -644,20 +645,39 @@ def downloadGraph(gClient,
                 edgeBatchI=0
                 while True:
                     try:
-                        edgeLookupReq=gClient.execute_query("LOOKUP ON {srcNodeType} WHERE {srcNodeType}.{srcNodeIdAttr}!='不可能的名字'|\
-                                                                GO FROM $-.VertexID OVER {edgeType} YIELD   {edgeType}._src AS srcSysID,\
-                                                                                                            {edgeType}._dst AS tgtSysID,\
-                                                                                                            $^.{srcNodeType}.{srcNodeIdAttr} AS {srcNodeType}{srcNodeIdAttr}_head,\
-                                                                                                            $$.{tgtNodeType}.{tgtNodeIdAttr} AS {tgtNodeType}{tgtNodeIdAttr}_tail|\
-                                                                                                                LIMIT {batchI},{batchSize}".format(
-                                                                                                                srcNodeType=srcVertexTypeItem_head,
-                                                                                                                srcNodeIdAttr=srcVertexKeynameDict[srcVertexTypeItem_head],
-                                                                                                                edgeType=edgeTypeItem,
-                                                                                                                tgtNodeType=tgtVertexTypeItem_tail,
-                                                                                                                tgtNodeIdAttr=srcVertexKeynameDict[tgtVertexTypeItem_tail],
-                                                                                                                batchI=edgeBatchI,
-                                                                                                                batchSize=edgeBatchSize
-                                                                                                            ))
+                        if sampleN==-1:
+                            edgeLookupReq=gClient.execute_query("LOOKUP ON {srcNodeType} WHERE {srcNodeType}.{srcNodeIdAttr}!='不可能的名字'|\
+                                                                    GO FROM $-.VertexID OVER {edgeType} YIELD   {edgeType}._src AS srcSysID,\
+                                                                                                                {edgeType}._dst AS tgtSysID,\
+                                                                                                                $^.{srcNodeType}.{srcNodeIdAttr} AS {srcNodeType}{srcNodeIdAttr}_head,\
+                                                                                                                $$.{tgtNodeType}.{tgtNodeIdAttr} AS {tgtNodeType}{tgtNodeIdAttr}_tail|\
+                                                                                                                    LIMIT {batchI},{batchSize}".format(
+                                                                                                                    srcNodeType=srcVertexTypeItem_head,
+                                                                                                                    srcNodeIdAttr=srcVertexKeynameDict[srcVertexTypeItem_head],
+                                                                                                                    edgeType=edgeTypeItem,
+                                                                                                                    tgtNodeType=tgtVertexTypeItem_tail,
+                                                                                                                    tgtNodeIdAttr=srcVertexKeynameDict[tgtVertexTypeItem_tail],
+                                                                                                                    batchI=edgeBatchI,
+                                                                                                                    batchSize=edgeBatchSize
+                                                                                                                ))
+                        else:
+                            searchStr="LOOKUP ON {srcNodeType} WHERE {srcNodeType}.{srcNodeIdAttr}!='不可能的名字'|LIMIT {batchI},{batchSize}|\
+                                                                    SAMPLE FROM $-.VertexID OVER {edgeType} YIELD   {edgeType}._src AS srcSysID,\
+                                                                                                                {edgeType}._dst AS tgtSysID,\
+                                                                                                                {edgeType}.score AS score\
+                                                                                                                LIMIT {sampleSize}".format(
+                                                                                                                    srcNodeType=srcVertexTypeItem_head,
+                                                                                                                    srcNodeIdAttr=srcVertexKeynameDict[srcVertexTypeItem_head],
+                                                                                                                    edgeType=edgeTypeItem,
+                                                                                                                    tgtNodeType=tgtVertexTypeItem_tail,
+                                                                                                                    tgtNodeIdAttr=srcVertexKeynameDict[tgtVertexTypeItem_tail],
+                                                                                                                    batchI=edgeBatchI,
+                                                                                                                    batchSize=edgeBatchSize,
+                                                                                                                    sampleSize=sampleN
+                                                                                                                )
+                            # print(searchStr)
+                            edgeLookupReq=gClient.execute_query(searchStr)
+
                         edgeLookupDf=wrapNebula2Df(edgeLookupReq).dropna()
                         if edgeLookupDf.shape[0]==0:
                             break
