@@ -31,7 +31,9 @@ def wrapNebula2Df(nebulaObj):
         myData=[]
         for row in nebulaObj.rows():
             try:
-                rowData=[valItem.value.decode("utf8") for valItem in row.values]
+                rowData=[valItem.value.decode("utf8") 
+                            if type(valItem.value)==bytes else valItem.value
+                            for valItem in row.values]
                 myData.append(rowData)
             except UnicodeDecodeError as ue:
                 print("encoding error")
