@@ -470,7 +470,10 @@ def buildGraphDB(gClient,uploadSchemaJson,realDbName=None,force=False):
     if realDbName is None:
         realDbName=uploadSchemaJson["gDbName"]
     
-    queryList=["DROP SPACE {} {};CREATE SPACE IF NOT EXISTS {}".format(isexist,realDbName,realDbName)]
+    queryList=[]
+    if force==True:
+        queryList=["DROP SPACE {} {}".format(isexist,realDbName)]
+    queryList+=["CREATE SPACE IF NOT EXISTS {}".format(realDbName)]
     
     for vertexInfo in uploadSchemaJson["vertex"]:
         attrNameTypeGroup=[(vertexInfo["csv2plato_attr_map"][attrKeyItem],
